Reklama
#2734031 18.04.2019 17:49:31
Część, jako, że mamy święto krótkofalowca udało nam się przygotować (nam czyli Fryderykowi i Damianowi) małe co nieco w temacie Hamnetu i VoIP
1) Hamnet we Wrocławiu. Mamy dwa linki
a) 44.165.100.0/24 - sieć aglomeracyjna
Obecne wysycenie IP sieć 100
44.165.100.2 gw sq6oxf
44.165.100.3 gw sq6xl
44.165.100.4 gw sq6xl
44.165.100.5 gw sp6ptt
44.165.100.6 gw sq6oxf
44.165.100.7 gw sq6oxf
44.165.100.8 gw sq6oxf
44.165.100.9 gw sq6oxf
44.165.100.10 gw sq6ncc
44.165.100.11 gw sq6ncc
44.165.100.12 gw sq6ncc
44.165.100.13 gw sq6ncc
44.165.100.14 gw sq6ncc
44.165.100.15 gw sq6oxf
44.165.100.251 gw sp6ptt
b) 44.165.101.0/24 - sieć miejska
Obecne wysycenie IP sieć 101
44.165.101.5 gw sq9rxf
44.165.101.15 gw sq9rxf
Węzeł komunikacyjny znajduję w chmurze do niego prowadzi tunel IPIP z sieci ampr.org. Z węzła do sieci docelowych prowadzone są tunele openvpn do poszczególnych użytkowników. Jest to realizowane poprzez Openvpn. Dla osób zainteresowanych sporządzane są odpowiednie dostępy a na samym serwerze dodawany odpowiedni wpis regulujący ruch według schematu
route add -net 44.165.101.0/24 gw sq9rhx
route add -host 44.165.100.2 gw sq6oxf
route add -host 44.165.100.3 gw sq6xl2
route add -host 44.165.100.4 gw sq6xl2
route add -host 44.165.100.5 gw sp6ptt
route add -host 44.165.100.6 gw sq6oxf
route add -host 44.165.100.7 gw sq6oxf
route add -host 44.165.100.8 gw sq6oxf
route add -host 44.165.100.9 gw sq6oxf
route add -host 44.165.100.10 gw sq6ncc
route add -host 44.165.100.11 gw sq6ncc
route add -host 44.165.100.12 gw sq6ncc
route add -host 44.165.100.13 gw sq6ncc
route add -host 44.165.100.14 gw sq6ncc
route add -host 44.165.100.15 gw sq6oxf
route add -host 44.165.100.251 gw sp6ptt
2) VoIP w Hamnet
a) Obecnie korzystamy z PBX opartego o Asterisk w Toruniu pod adresem sp2pmk.ampr.org (44.165.33.1) który jest pod zarządzaniem kolegi Waldka, ukłony za pomoc w konfiguracji. Sama konfiguracja jest opisana jest pod tym linkiem http://sp2ong.noip.pl/pl/hamnet Status PBX pod adresem http://sp2pmk.ampr.org/status/
b) aby konfiguracja działała na końcówce naszego tunelu należy uruchomić w odpowiedni sposób przekazywanie pakietów. Poniżej przykład konfiguracji sieciowej dla telefonu o adresie 44.165.100.7 i rzeczywistym adresie sieciowym 192.168.20.111 w sieci domowej. Na końcówce tunelu (routerze) należy dodać
###Telefon NAT 1:1
iptables -t nat -A PREROUTING -d 44.165.100.7 -j DNAT --to-destination 192.168.20.111
iptables -t nat -A POSTROUTING -s 192.168.20.111 -o tun0 -j SNAT --to-source 44.165.100.7
Jeżeli chcemy mieć Hamnet w sieci domowej (tutaj sieć domowa to 192.168.20/24) należy dodać na końcówce tunelu i zarazem routerze. IP 44.165.100.9 to IP przypisanego IP w sieci hamnet, po tym ip będziemy identyfikowanie przeglądając zasoby hamnet z domowych urządzeń
###Ogolna DYNAMIC NAT
iptables -t nat -A POSTROUTING -o tun0 -s 192.168.20.0/24 -j SNAT --to-source 44.165.100.9
3) Konfiguracja telefonu Cisco 7941G
a) główna konfiguracja telefonu znajduje się w pliku SEP001E4AF0E19B.cnf.xml. Należy tam pisać swój numer telefonu
linia 100 <,name>,numertelefonu<,/name>,
linia 101 <,displayName>,numertelefonu<,/displayName>,
linia 106 <,authName>,numertelefonu<,/authName>,
zgodnie z opisaną instrukcją oraz wpisać hasło linia 107 <,authPassword>,hasło<,/authPassword>,
b) firmware należy załadować poprzez serwer tftp z adresu 172.16.1.1. Sam telefon Cisco 7941G uruchamiamy w tryb programowania poprzez restart twardy telefonu z wciśniętym klawiszem # oraz wpisanie sekwencji 123456789*0# podczas migania diod LED linii. Ekran wtedy robi się czarny. Upgrade firmaware trwa dość długi czas ale po chwili powinniśmy cieszyć się naszym telefonem
c) A tak to wygląda w rzeczywistości
A tu krótki filmik z dzwonienia plus przeglądanie zasobów apmprenetu ,)
https://youtu.be/XbDTLS85iBY
pozdrawiam Fryderyk SQ6OXF
p.s. bardzo dziękuje Waldkowi SP2ONG za pomoc i Damianowi SQ9RHX za długie spędzone razem godziny nad konsolą
1) Hamnet we Wrocławiu. Mamy dwa linki
a) 44.165.100.0/24 - sieć aglomeracyjna
Obecne wysycenie IP sieć 100
44.165.100.2 gw sq6oxf
44.165.100.3 gw sq6xl
44.165.100.4 gw sq6xl
44.165.100.5 gw sp6ptt
44.165.100.6 gw sq6oxf
44.165.100.7 gw sq6oxf
44.165.100.8 gw sq6oxf
44.165.100.9 gw sq6oxf
44.165.100.10 gw sq6ncc
44.165.100.11 gw sq6ncc
44.165.100.12 gw sq6ncc
44.165.100.13 gw sq6ncc
44.165.100.14 gw sq6ncc
44.165.100.15 gw sq6oxf
44.165.100.251 gw sp6ptt
b) 44.165.101.0/24 - sieć miejska
Obecne wysycenie IP sieć 101
44.165.101.5 gw sq9rxf
44.165.101.15 gw sq9rxf
Węzeł komunikacyjny znajduję w chmurze do niego prowadzi tunel IPIP z sieci ampr.org. Z węzła do sieci docelowych prowadzone są tunele openvpn do poszczególnych użytkowników. Jest to realizowane poprzez Openvpn. Dla osób zainteresowanych sporządzane są odpowiednie dostępy a na samym serwerze dodawany odpowiedni wpis regulujący ruch według schematu
route add -net 44.165.101.0/24 gw sq9rhx
route add -host 44.165.100.2 gw sq6oxf
route add -host 44.165.100.3 gw sq6xl2
route add -host 44.165.100.4 gw sq6xl2
route add -host 44.165.100.5 gw sp6ptt
route add -host 44.165.100.6 gw sq6oxf
route add -host 44.165.100.7 gw sq6oxf
route add -host 44.165.100.8 gw sq6oxf
route add -host 44.165.100.9 gw sq6oxf
route add -host 44.165.100.10 gw sq6ncc
route add -host 44.165.100.11 gw sq6ncc
route add -host 44.165.100.12 gw sq6ncc
route add -host 44.165.100.13 gw sq6ncc
route add -host 44.165.100.14 gw sq6ncc
route add -host 44.165.100.15 gw sq6oxf
route add -host 44.165.100.251 gw sp6ptt
2) VoIP w Hamnet
a) Obecnie korzystamy z PBX opartego o Asterisk w Toruniu pod adresem sp2pmk.ampr.org (44.165.33.1) który jest pod zarządzaniem kolegi Waldka, ukłony za pomoc w konfiguracji. Sama konfiguracja jest opisana jest pod tym linkiem http://sp2ong.noip.pl/pl/hamnet Status PBX pod adresem http://sp2pmk.ampr.org/status/
b) aby konfiguracja działała na końcówce naszego tunelu należy uruchomić w odpowiedni sposób przekazywanie pakietów. Poniżej przykład konfiguracji sieciowej dla telefonu o adresie 44.165.100.7 i rzeczywistym adresie sieciowym 192.168.20.111 w sieci domowej. Na końcówce tunelu (routerze) należy dodać
###Telefon NAT 1:1
iptables -t nat -A PREROUTING -d 44.165.100.7 -j DNAT --to-destination 192.168.20.111
iptables -t nat -A POSTROUTING -s 192.168.20.111 -o tun0 -j SNAT --to-source 44.165.100.7
Jeżeli chcemy mieć Hamnet w sieci domowej (tutaj sieć domowa to 192.168.20/24) należy dodać na końcówce tunelu i zarazem routerze. IP 44.165.100.9 to IP przypisanego IP w sieci hamnet, po tym ip będziemy identyfikowanie przeglądając zasoby hamnet z domowych urządzeń
###Ogolna DYNAMIC NAT
iptables -t nat -A POSTROUTING -o tun0 -s 192.168.20.0/24 -j SNAT --to-source 44.165.100.9
3) Konfiguracja telefonu Cisco 7941G
a) główna konfiguracja telefonu znajduje się w pliku SEP001E4AF0E19B.cnf.xml. Należy tam pisać swój numer telefonu
linia 100 <,name>,numertelefonu<,/name>,
linia 101 <,displayName>,numertelefonu<,/displayName>,
linia 106 <,authName>,numertelefonu<,/authName>,
zgodnie z opisaną instrukcją oraz wpisać hasło linia 107 <,authPassword>,hasło<,/authPassword>,
b) firmware należy załadować poprzez serwer tftp z adresu 172.16.1.1. Sam telefon Cisco 7941G uruchamiamy w tryb programowania poprzez restart twardy telefonu z wciśniętym klawiszem # oraz wpisanie sekwencji 123456789*0# podczas migania diod LED linii. Ekran wtedy robi się czarny. Upgrade firmaware trwa dość długi czas ale po chwili powinniśmy cieszyć się naszym telefonem
c) A tak to wygląda w rzeczywistości
A tu krótki filmik z dzwonienia plus przeglądanie zasobów apmprenetu ,)
https://youtu.be/XbDTLS85iBY
pozdrawiam Fryderyk SQ6OXF
p.s. bardzo dziękuje Waldkowi SP2ONG za pomoc i Damianowi SQ9RHX za długie spędzone razem godziny nad konsolą
wpis edytowany 18.04.2019 17:51:57
#2735183 18.04.2019 19:53:32
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
wpis edytowany 18.04.2019 19:55:55
"Panta rej" jak mawiał Demokles z Akwirynu
SR6MA w mobilku 145.350 home
SR6MA w mobilku 145.350 home
#2737062 18.04.2019 23:15:35
sq6ade pisze:
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Cześć i zasadniczo nic się nie zmieniło, dalej jest "eter", dalej wymienia się informację, tylko o wiele szybciej, zupełnie inaczej a przede wszystkim poprzez inna infrastrukturę. Trzeba pamiętać, że idea wspierania budowy alternatywnej sieci przypominającej internet jest jak najbardziej wskazana chociażby ze względów bezpieczeństwa itp. Zapraszam do zapoznania się z http://wiki.hamnet.ugu.pl/download/HamNET.pdf oraz http://wiki.hamnet.ugu.pl/download/HamNET-VoIP.pdf
pozdrawiam F
wpis edytowany 18.04.2019 23:30:00
#2742713 19.04.2019 09:43:54
SQ6OXF pisze:
Cześć i zasadniczo nic się nie zmieniło, dalej jest "eter", dalej wymienia się informację, tylko o wiele szybciej, zupełnie inaczej a przede wszystkim poprzez inna infrastrukturę. Trzeba pamiętać, że idea wspierania budowy alternatywnej sieci przypominającej internet jest jak najbardziej wskazana chociażby ze względów bezpieczeństwa itp. Zapraszam do zapoznania się z http://wiki.hamnet.ugu.pl/download/HamNET.pdf oraz http://wiki.hamnet.ugu.pl/download/HamNET-VoIP.pdf
pozdrawiam F
sq6ade pisze:
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Cześć i zasadniczo nic się nie zmieniło, dalej jest "eter", dalej wymienia się informację, tylko o wiele szybciej, zupełnie inaczej a przede wszystkim poprzez inna infrastrukturę. Trzeba pamiętać, że idea wspierania budowy alternatywnej sieci przypominającej internet jest jak najbardziej wskazana chociażby ze względów bezpieczeństwa itp. Zapraszam do zapoznania się z http://wiki.hamnet.ugu.pl/download/HamNET.pdf oraz http://wiki.hamnet.ugu.pl/download/HamNET-VoIP.pdf
pozdrawiam F
O ile dobrze rozumiem konfigurację opisaną w pierwszym poście, to trudno nazwać to alternatywą dla internetu - internet jest tutaj warstwą transportową dla tuneli OpenVPN i całej opisanej sieci mającej tyle wspólnego z HAMNET, że używa adresacji tejże.
IMO idea HAMNET to bardziej samodzielnie ogarnięcie warstwy fizycznej transportu, np. poprzez sieć radiową działającą na częstotliwościach dostępnych dla amatorów.
EDIT
Rozwijając, sieć DMR w kontekście sieci kryzysowej jest także upośledzona ponieważ działa w oparciu o internet. W sumie to dość zabawne, bo zapewnia się przemiennikom zasilanie awaryjne, etc, a pierwsza rzecz która padnie w sytuacji kryzysowej to telekomunikacja zamieniając wszystkie przemienniki w samotne wyspy.
Gdyby udało się zbudować lokalną, lub ogólnopolską sieć HAMNET i użyć jej do linkowania przemienników DMR można by mówić o faktycznie niezależnej sieci, przydatnej w sytuacji kryzysowej.
wpis edytowany 19.04.2019 09:54:20
#2743140 19.04.2019 10:30:50
Odnosnie DMR to jest Master Server DMR w sieci Hamnet BM2001 tak wiec jesli istnieje lacznosc na poziomie radiowym w sieci radiowej to pod adresem 44.148.230.201 jest dostepny Master Sevrer BM wiec lacznosc moze byc prowadzona na DMR w ramach siec HamNET
Wiecej o tym
http://bm262.de/bm-goes-hamnet/
Wiecej o tym
http://bm262.de/bm-goes-hamnet/
73 Waldek SP2ONG
#2746223 19.04.2019 16:05:56
cos mi jesze wyglada ze alokacja 44.165.100.xx wymagalaby rezerwacji u koordynatora AMPRNETu. Przypisanie znakow do tych IP w latach 90-tych ubieglego wieku bylo inne
. Fakt ze w tamtych czasach osob pracujacych AX25 z adresacja IP bylo niewiele ale rezerwacje u koordynatora chyba nie byly odwolywane 
wpis edytowany 19.04.2019 16:07:39
#2746795 19.04.2019 17:06:28
a kto te adresy 44 przydziela ?
Artur VSS
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
#2746926 19.04.2019 17:20:50
Wiecej informacji o HamNET adresacji IP, koordynatorach znajdziecie na forum o HamNET:
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
wpis edytowany 19.04.2019 17:21:12
73 Waldek SP2ONG
#2746947 19.04.2019 17:23:26
lata temu lokalny koordynator amprnetu ale tyle lat minelo ... Musialbym odkopac archiwum digestow z SR6BOX'a czy BBS'a a nie wiem czy gdzies sie zachowalo. W Internecie szukalem ale bez sukcesu
#2747065 19.04.2019 17:36:00
sp2ong pisze:
Wiecej informacji o HamNET adresacji IP, koordynatorach znajdziecie na forum o HamNET:
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
Wiecej informacji o HamNET adresacji IP, koordynatorach znajdziecie na forum o HamNET:
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
Artur VSS
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
Reklama
#2747099 19.04.2019 17:39:35
VSS pisze:
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
A chcialo ci sie zerknac na te strone co podalem http://hamnet.ehion.com/?kontakt
wpis edytowany 19.04.2019 19:55:41
73 Waldek SP2ONG
#2747779 19.04.2019 19:31:32
sp6ryd pisze:
lata temu lokalny koordynator amprnetu ale tyle lat minelo ... Musialbym odkopac archiwum digestow z SR6BOX'a czy BBS'a a nie wiem czy gdzies sie zachowalo. W Internecie szukalem ale bez sukcesu
lata temu lokalny koordynator amprnetu ale tyle lat minelo ... Musialbym odkopac archiwum digestow z SR6BOX'a czy BBS'a a nie wiem czy gdzies sie zachowalo. W Internecie szukalem ale bez sukcesu
W tamtych latach gdy we Wrocławiu był czynny działający węzeł PR SR6BOX
(Wezel uruchomiono w Lipiec 1993 r. I wezel zlikwidowano w wrzesniu 2004 r).
To lokalnym koordynatorem był SP6GPJ. Aktualnie jak jest z koordynacją polecam
forum http://forum.hamnet.ugu.pl -należy się zarejstrować.
73 ` Marian
#2747789 19.04.2019 19:43:29
sp6ryd pisze:
cos mi jesze wyglada ze alokacja 44.165.100.xx wymagalaby rezerwacji u koordynatora AMPRNETu. Przypisanie znakow do tych IP w latach 90-tych ubieglego wieku bylo inne
. Fakt ze w tamtych czasach osob pracujacych AX25 z adresacja IP bylo niewiele ale rezerwacje u koordynatora chyba nie byly odwolywane 
cos mi jesze wyglada ze alokacja 44.165.100.xx wymagalaby rezerwacji u koordynatora AMPRNETu. Przypisanie znakow do tych IP w latach 90-tych ubieglego wieku bylo inne
Gdybyś uważnie czytał to na prośbę byłego koordynatora HF1L (ex SP1LOP) zamieścilem
tu na forum informację nt. porządkowania przyznanych adresów ip i wykasowanie przydziału.
Wiele adresów z puli amprnet było martwych. Więc główny koordynator amprnet poprosił o
dokonanie w SP uporządkowania listy.
I u koordynatora AMPRNET nie robi się rezerwacji ip, to on przydziela ip.
73 ` Marian
#2747828 19.04.2019 20:08:52
sp2ong pisze:
A chcialo ci sie zerknac na te strone co podalem http://hamnet.ehion.com/?kontakt
szybciej bys kliknal myszka na link niz napisanie tego postu ,)
VSS pisze:
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
A chcialo ci sie zerknac na te strone co podalem http://hamnet.ehion.com/?kontakt
to mi nic nie mówi, jak chciałbym zobaczyć spis przyznanych adresów IP, chyba nie jest to tajna rzecz i na stronie HAMNETU można to zamiescić
Artur VSS
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
https://sp3vss.eu
PZK - Piraci Z Karaibów
Udostępniający link nie odpowiada z automatu za treść:
https://tiny.pl/tqrng
http://hudoc.echr.coe.int/eng?i=001-187930
#2747844 19.04.2019 20:19:37
VSS pisze:
to mi nic nie mówi, jak chciałbym zobaczyć spis przyznanych adresów IP, chyba nie jest to tajna rzecz i na stronie HAMNETU można to zamiescić
to mi nic nie mówi, jak chciałbym zobaczyć spis przyznanych adresów IP, chyba nie jest to tajna rzecz i na stronie HAMNETU można to zamiescić
Pytaj o to koordynatora masz do niego kontakt nie wiem czy jest aktualna lista obecnie po zmianie koordynatora
73 Waldek SP2ONG
#2747858 19.04.2019 20:30:00
VSS pisze:
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
sp2ong pisze:
Wiecej informacji o HamNET adresacji IP, koordynatorach znajdziecie na forum o HamNET:
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
Wiecej informacji o HamNET adresacji IP, koordynatorach znajdziecie na forum o HamNET:
http://forum.hamnet.ugu.pl (wymagana rejestracja)
lub http://hamnet.ehion.com/
pytam bo prawie 30 lat temu dostałem adres w puli 44 i pytam czy to obecnie ktoś ogarnia
aktualnym koordynatorem jest Brian Kantor Brian@ampr.org
pomaga mu sq6elq dezert@r.ehion.com
73 ` Marian
#2747869 19.04.2019 20:50:36
oki. nie mam jakiegos szczegolnego sentymentu do przyznanego mi wtedy, w pionierskich czsach packet radio, adresu. Wtedy nie bylo jeszcze hamnetu. Nie sledzilem zmian i moze faktycznie przeoczylem ze hamnet przejal administracje pula ip przyznana dla Polski w sieci AMPRNET. Duzo by mozna w takim razie pisac czym jest a czym moglby byc hamnet. Zgadzam sie zasadniczo z przedmowca ze im wiecej 'ip w radiu' lub jak kto woli 'radia w ip' tym lepiej byle tylko nie na standardowym niemodyfikowanym WiFi. Co do samej rejestracji to o ile wykorzystuje link wylacznie radiowy to nie powinno to byc konieczne bo nadawac pod moim znakiem moze tylko moja stacja.
#2748013 20.04.2019 01:11:02
SO9W pisze:
O ile dobrze rozumiem konfigurację opisaną w pierwszym poście, to trudno nazwać to alternatywą dla internetu - internet jest tutaj warstwą transportową dla tuneli OpenVPN i całej opisanej sieci mającej tyle wspólnego z HAMNET, że używa adresacji tejże.
IMO idea HAMNET to bardziej samodzielnie ogarnięcie warstwy fizycznej transportu, np. poprzez sieć radiową działającą na częstotliwościach dostępnych dla amatorów.
EDIT
Rozwijając, sieć DMR w kontekście sieci kryzysowej jest także upośledzona ponieważ działa w oparciu o internet. W sumie to dość zabawne, bo zapewnia się przemiennikom zasilanie awaryjne, etc, a pierwsza rzecz która padnie w sytuacji kryzysowej to telekomunikacja zamieniając wszystkie przemienniki w samotne wyspy.
Gdyby udało się zbudować lokalną, lub ogólnopolską sieć HAMNET i użyć jej do linkowania przemienników DMR można by mówić o faktycznie niezależnej sieci, przydatnej w sytuacji kryzysowej.
SQ6OXF pisze:
Cześć i zasadniczo nic się nie zmieniło, dalej jest "eter", dalej wymienia się informację, tylko o wiele szybciej, zupełnie inaczej a przede wszystkim poprzez inna infrastrukturę. Trzeba pamiętać, że idea wspierania budowy alternatywnej sieci przypominającej internet jest jak najbardziej wskazana chociażby ze względów bezpieczeństwa itp. Zapraszam do zapoznania się z http://wiki.hamnet.ugu.pl/download/HamNET.pdf oraz http://wiki.hamnet.ugu.pl/download/HamNET-VoIP.pdf
pozdrawiam F
sq6ade pisze:
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Siemanko.
Przyznam że nie ogarniam tej idei Hamnet. Kiedyś te wydzielone 44 służyło owszem ale medium był tzw. eter , fale radiowe pasm Hamsiaków na usługach PR.
Co jest tutaj medium ? WiFi i Bt ?
Cześć i zasadniczo nic się nie zmieniło, dalej jest "eter", dalej wymienia się informację, tylko o wiele szybciej, zupełnie inaczej a przede wszystkim poprzez inna infrastrukturę. Trzeba pamiętać, że idea wspierania budowy alternatywnej sieci przypominającej internet jest jak najbardziej wskazana chociażby ze względów bezpieczeństwa itp. Zapraszam do zapoznania się z http://wiki.hamnet.ugu.pl/download/HamNET.pdf oraz http://wiki.hamnet.ugu.pl/download/HamNET-VoIP.pdf
pozdrawiam F
O ile dobrze rozumiem konfigurację opisaną w pierwszym poście, to trudno nazwać to alternatywą dla internetu - internet jest tutaj warstwą transportową dla tuneli OpenVPN i całej opisanej sieci mającej tyle wspólnego z HAMNET, że używa adresacji tejże.
IMO idea HAMNET to bardziej samodzielnie ogarnięcie warstwy fizycznej transportu, np. poprzez sieć radiową działającą na częstotliwościach dostępnych dla amatorów.
EDIT
Rozwijając, sieć DMR w kontekście sieci kryzysowej jest także upośledzona ponieważ działa w oparciu o internet. W sumie to dość zabawne, bo zapewnia się przemiennikom zasilanie awaryjne, etc, a pierwsza rzecz która padnie w sytuacji kryzysowej to telekomunikacja zamieniając wszystkie przemienniki w samotne wyspy.
Gdyby udało się zbudować lokalną, lub ogólnopolską sieć HAMNET i użyć jej do linkowania przemienników DMR można by mówić o faktycznie niezależnej sieci, przydatnej w sytuacji kryzysowej.
Cześć, wiesz od czegoś trzeba zacząć, sieć sama się nie zbuduje a odległości są w chwili obecnej dość znaczne, jeżeli będziemy mieć większe zagęszczenie umożliwiające połączeni direct to jak najbardziej będziemy przechodzić na takie połączenia
pozdrawiam F
wpis edytowany 20.04.2019 01:22:17
#2748016 20.04.2019 01:12:29
sp6ryd pisze:
cos mi jesze wyglada ze alokacja 44.165.100.xx wymagalaby rezerwacji u koordynatora AMPRNETu. Przypisanie znakow do tych IP w latach 90-tych ubieglego wieku bylo inne
. Fakt ze w tamtych czasach osob pracujacych AX25 z adresacja IP bylo niewiele ale rezerwacje u koordynatora chyba nie byly odwolywane 
cos mi jesze wyglada ze alokacja 44.165.100.xx wymagalaby rezerwacji u koordynatora AMPRNETu. Przypisanie znakow do tych IP w latach 90-tych ubieglego wieku bylo inne
rzeczy i miejsca porzucone zmieniają właściciela, adresy zostały nam oficjalnie przyznane jak chcesz się pobawić to chętnie tunel Ci założę
pozdr F
wpis edytowany 20.04.2019 01:18:06
#2748017 20.04.2019 01:14:32
VSS pisze:
a kto te adresy 44 przydziela ?
a kto te adresy 44 przydziela ?
O adres możesz wnioskować poprzez portal https://portal.ampr.org/login.php
pozdr F
Reklama